<?php
/*
Plugin Name: CaPa Protect
Plugin URI: http://www.smatern.de/category/coding/capa/
Description: Protects Categories, Pages and Posts from specific users.
Version: 0.5.4.2
Author: S. Matern
Author URI: http://www.smatern.de
*/

load_plugin_textdomain('capa', $path='wp-content/plugins/capa');

include_once('capa-options.php');
include_once('capa-user-edit.php');

// --------------------------------------------------------------------
global $capa_protect_private_message;

$capa_protect_private_message 						= get_option("capa_protect_private_message");
$capa_protect_post_policy 							= get_option('capa_protect_post_policy');
$capa_protect_default_private_message 				= __('Sorry, you do not have sufficient privileges to view this post.', 'capa-protect');;
$capa_protect_show_private_message					= get_option('capa_protect_show_private_message');
$capa_protect_show_private_categories 				= get_option('capa_protect_show_private_categories');
$capa_protect_show_private_pages 					= get_option('capa_protect_show_private_pages');
$capa_protect_show_padlock_on_private_posts 		= get_option('capa_protect_show_padlock_on_private_posts');
$capa_protect_show_padlock_on_private_categories 	= get_option('capa_protect_show_padlock_on_private_categories');
$capa_protect_show_comment_on_private_posts			= get_option('capa_protect_show_comment_on_private_posts');
$capa_protect_show_title_in_feeds					= get_option('capa_protect_show_title_in_feeds');
$capa_protect_advance_policy						= get_option('capa_protect_advance_policy');
$capa_protect_comment_policy						= get_option('capa_protect_comment_policy');
$capa_protect_default_comment_author				= __('Unknown','capa-protect');

$access_pag_anonymous	= get_option("capa_protect_pag_anonymous");
$access_pag_default		= get_option("capa_protect_pag_default");
$access_cat_anonymous	= get_option("capa_protect_cat_anonymous");
$access_cat_default		= get_option("capa_protect_cat_default");


// Decloration of WP Variables
$wpc_all_category_ids 	= get_all_category_ids();
$wpc_all_page_ids		= get_all_page_ids();
$wpc_siteurl 			= get_settings('siteurl');

class capa_protect {

	function filter_category_list_item($text,$category = null){

		global $capa_protect_show_private_categories;
		global $capa_protect_show_padlock_on_private_categories;

		global $wpc_all_category_ids;
		global $current_user;
		global $wpc_siteurl;

		if ($current_user->has_cap('manage_categories') && !$current_user->caps['editor']){
			return $text;
		}

		# Make the changes
		$site_root = parse_url($wpc_siteurl);
		$site_root = trailingslashit($site_root['path']);

		if($capa_protect_show_private_categories){
			if($capa_protect_show_padlock_on_private_categories){
					foreach ($wpc_all_category_ids as $possible_category_id){
						if (!capa_protect::user_can_access($possible_category_id, $current_user,'cat')){
							$tmp_catname = get_catname($possible_category_id);
							$search[$possible_category_id] = "#>".$tmp_catname."<#";
							$replace[$possible_category_id] = '><img src="' . $site_root .'wp-content/plugins/capa/img/padlock.gif" height="10" width="10" valign="center" border="0"/> '. $tmp_catname.'<';
						}
					}

				// In the case user see all categories but padlock is active
				// $search will be empty
					return (count($search) > 0) ? preg_replace($search,$replace,$text) : $text;


			}
			return $text;
		}
		return $text;
	}

	function filter_page_list_item(){

		global $access_pag_anonymous;
		global $access_pag_default;
		global $wpc_all_page_ids;
		global $capa_protect_show_private_pages;

	// Show Private Pages
		if($capa_protect_show_private_pages)
			return FALSE;

		$current_user = wp_get_current_user();
		$current_role = implode('',$current_user->roles);

		$excludes_page = $wpc_all_page_ids;  // If the DB contain no Data. All Pages will be excludes
	
		if ($current_user->has_cap('manage_categories') && !$current_user->caps['editor'])
			return array('');

			if ($current_user->id == 0){
				$user_access_page_check = $access_pag_anonymous;
			}else{
				$user_access_page_check = get_option("capa_protect_pag_user_".$current_user->id);
			}

			if(empty($user_access_page_check)){
				if($current_role){
					$user_access_page_check = get_option("capa_protect_pag_role_".$current_role);
				}else{
					$user_access_page_check	= $access_pag_default;
				}
			}

			if(is_array($user_access_page_check)){
				$tmp['all_pages'] = $wpc_all_page_ids;

				foreach($user_access_page_check as $check=>$id){
					$tmp_id = array_search($id,$tmp['all_pages']);
					if($tmp_id !== FALSE){
						unset($tmp['all_pages'][$tmp_id]);
					}
				}

				$tmp['all_pages'] = array_flip($tmp['all_pages']);
				$excludes_page = array_keys($tmp['all_pages']);
			}

			return $excludes_page;

	}

	// --------------------------------------------------------------------

	function post_should_be_hidden($postid){
		if (!isset($postid))
			return true;

		global $current_user;
		global $capa_protect_post_policy;

		// Bad! To much queries
		// find a better way
		$post_categories = wp_get_post_categories($postid);
		$post_val		 = get_post($postid);
		$post_cat_pa	 = $post_val->post_parent;

		// CATEGORY
		if ($capa_protect_post_policy != 'hide') {
		// Page
			if ($post_val->post_type == "page") {
				if (capa_protect::user_can_access($postid, $current_user,'pag'))
					return false;
			}

		// Show a Patlock
			foreach ($post_categories as $post_category_id)
				if (capa_protect::user_can_access($post_category_id, $current_user,'cat'))
					return false;

			return true;
		
		} else {
			// Bastion ( Show or not Show )
			// Check Up ~ Provsional Info: There is a previous Entry (?) //
			if ($post_val->post_type == "page") {
				if (!capa_protect::user_can_access($postid, $current_user,'pag'))
					return true;
			} else {

				// Category Post
				return !capa_protect::user_can_access($post_categories, $current_user,'cat',$post_cat_pa);
			}
		}

	}

	// --------------------------------------------------------------------

	function user_can_access($val_id,$user,$kind,$parent_id=''){
		global $post;

		if ($user->has_cap('manage_categories')  && !$user->caps['editor'])
			return true;

		global $access_pag_anonymous;
		global $access_pag_default;
		global $access_cat_anonymous;
		global $access_cat_default;

		switch($kind) {
	
		case 'pag':

			if ($user->id == 0)
				$user_access_page_check = $access_pag_anonymous;
			else
				$user_access_page_check = get_option("capa_protect_pag_user_{$user->id}");

			if (empty($user_access_page_check))
			// Group Settings
				$tmp_caps = implode('',array_keys($user->caps));
				$user_access_page_check = get_option("capa_protect_pag_role_{$tmp_caps}");

			// Default Setting
			if (empty($user_access_page_check))
				$user_access_page_check	= $access_pag_default;

			if ($user_access_page_check[$val_id])
				return true;
			else
				return false;
		
			$user_access_pag_check = "";
			break 1;	

		case 'cat':

		// parent id check for attachment
			if ( is_attachment() ) {
				$access_post	= wp_get_post_cats(1,$parent_id);
				$val_id			= $access_post[0];
			}

			if ($user->id == 0){
				$user_access_category_check	= $access_cat_anonymous;
			}else{
				$user_access_category_check = get_option("capa_protect_cat_user_{$user->id}");
			}

		// User Settings
				if (empty($user_access_category_check)){
					// Group Settings
						$tmp_caps = implode('',array_keys($user->caps));
						$user_access_category_check = get_option("capa_protect_cat_role_{$tmp_caps}");
				}

				// Default Setting
					if(empty($user_access_category_check)){
						$user_access_category_check = $access_cat_default;
					}

			$return = FALSE;

			if($user_access_category_check !== FALSE){
				if(is_array($val_id)){
					foreach($val_id as $key=>$id){
						if(in_array($id,$user_access_category_check)){
							$return = TRUE;
						}
					}
				}else{
					if ($user_access_category_check[$val_id]){
						$return = TRUE;
					}
				}
			}

			return $return;

			$user_access_category_check = "";
			break 1;
		}

	}

	// --------------------------------------------------------------------

	function get_private_message() {
		global $post;
		global $capa_protect_private_message;
		global $capa_protect_default_private_message;

		$message = $capa_protect_private_message;

		if ($message == null)
			$message = $capa_protect_default_private_message;
		
		return $message;
	}

	// --------------------------------------------------------------------

	function get_capa_protect_for_user($current_user) {

		global $access_cat_anonymous;
		global $access_cat_default;

		if ($current_user->has_cap('manage_categories') && !$current_user->caps['editor']){
			return true;
		}

		$user_id = $current_user->id;

		if ($user_id == 0)
			return $access_cat_anonymous;

		$visible = get_option("capa_protect_cat_user_${user_id}");

		if (empty($visible)){
			$visible = get_option("capa_protect_cat_role_".implode('',$current_user->roles));

			if(empty($visible)){
				$visible = $access_cat_default;	
			}
		}

		return $visible;
	}

	// --------------------------------------------------------------------

	function set_access_for_user($user_id, $value, $kind) {
	
		switch($kind) {
			case "cat":
				if ($value){
					update_option("capa_protect_cat_user_${user_id}", $value);
				}else{
					update_option("capa_protect_cat_user_${user_id}", '0');
				}
			break;

			case "pag":
				if ($value){
					update_option("capa_protect_pag_user_${user_id}", $value);
				}else{
					update_option("capa_protect_pag_user_${user_id}", '0');
				}
			break;
		}

	}

	// --------------------------------------------------------------------

	function filter_posts($sql){

		global $current_user;
			if ($current_user->has_cap('manage_categories') && !$current_user->caps['editor']){
				return $sql;
			}

		global $capa_protect_show_title_in_feeds;
		global $capa_protect_post_policy;

		// static = WP Version 2.0
		// FEED Control
		// Edit 

/*
		if (is_feed() && $capa_protect_show_title_in_feeds || strpos($sql, 'post_status = "static"') !== false || strpos($sql, 'post_type = \'page\'') !== false){
			return $sql;
		}
*/

		if (!is_feed() && ( $capa_protect_post_policy == 'show title' || $capa_protect_post_policy == 'show message' )){
			return $sql;
		}

		global $wpdb;

		$inclusive		= capa_protect::get_value_categories(TRUE);
		$inclusive_page	= capa_protect::get_valid_pages();

		(sizeof($inclusive) <= 0) ? $inclusive = array(0) : $inclusive = $inclusive;

		$query = " SELECT ID FROM $wpdb->posts INNER JOIN" .
			" $wpdb->term_relationships ON ( $wpdb->posts.ID = $wpdb->term_relationships.object_id )" .
			" WHERE 0 = 1";

			$query .= " OR $wpdb->term_relationships.term_taxonomy_id in ( ".implode(',',$inclusive)." )";

		$res = mysql_query($query) or die(mysql_error());
		$ids = array();

		while ($row = mysql_fetch_assoc($res))
			$ids[] = "'" . $row['ID'] . "'";

		# Array Post Check ~ Include already the ID of Pages?
		if(sizeof($inclusive_page) > 0){
			$tmp_count = count($inclusive_page)-1;	

			for($i=0;$i<=$tmp_count;$i++){
				$tmp_var = "'".$inclusive_page[$i]."'";
				if(array_search($tmp_var,$ids) != 1){
					array_push($ids,"'".$inclusive_page[$i]."'");
				}
			}
		}

		if(sizeof($ids) > 0){
			$sql .= " AND ID IN (".implode(",",$ids).")";
		}else{
			$sql .= " AND ID IN ('0')";
		}

		return $sql;

	}

	// --------------------------------------------------------------------

	function filter_post_title($param){
		global	$post;
			if(is_null($post)){
				return $param;
			}

		global	$capa_protect_post_policy;

				$user = wp_get_current_user();

		if ($user->has_cap('manage_categories')  && !$user->caps['editor']){
			return $param;
		}

		if(capa_protect::post_should_be_hidden($post->ID)){
			if($capa_protect_post_policy !== FALSE && $capa_protect_post_policy != 'hide'){
				return $param;
			}else{
				return __('No Title','capa');
			}
		}else{
			return $param;
		}

	}

	// --------------------------------------------------------------------

	function filter_content($text){
		global $post;
		global $capa_protect_post_policy;

		if($capa_protect_post_policy != 'show message'){

			if(capa_protect::post_should_be_hidden($post->ID)){
				if($capa_protect_post_policy !== FALSE && $capa_protect_post_policy == 'show title'){
					$text = capa_protect::get_private_message();
				}
			}
		}

		return $text;
	}


	// --------------------------------------------------------------------

	function filter_comment($params){

		global $capa_protect_comment_policy;
		global $capa_protect_show_comment_on_private_posts;

		if(capa_protect::post_should_be_hidden($params->comment_post_ID)){
			if($capa_protect_comment_policy == 'show message' or $capa_protect_comment_policy == 'all'){
				return $params;
			}else{
				return FALSE;
			}
		}else{
			return FALSE;
		}

		return $params;

	}

	// --------------------------------------------------------------------

	function filter_comment_body($param){
		global $current_user;
		global $post;
		global $capa_protect_comment_policy;
		global $capa_protect_show_comment_on_private_posts;

		if ($current_user->has_cap('manage_categories')  && !$current_user->caps['editor']){
			return $param;
		}

		if(capa_protect::post_should_be_hidden($post->ID)){
			if(!is_numeric($capa_protect_show_comment_on_private_posts)){
				if($capa_protect_comment_policy == 'show message' or $capa_protect_comment_policy == 'all'){
					return $param;
				}else{
					return capa_protect::get_private_message();
				}
			}else{
				return $param;
			}
		}else{
			return $param;
		}
	}

	// --------------------------------------------------------------------

	function filter_comment_author($param){
		global $capa_protect_show_comment_on_private_posts;
		global $capa_protect_default_comment_author;
		global $capa_protect_comment_policy;
		global $post;

		// ADMIN AREA QUESTION
		global $current_user;


		if ($current_user->has_cap('manage_categories')  && !$current_user->caps['editor']){
			return $param;
		}

		if(capa_protect::post_should_be_hidden($post->ID)){
			if(!is_numeric($capa_protect_show_comment_on_private_posts)){
				if($capa_protect_comment_policy == 'show message' or $capa_protect_comment_policy == 'all'){
					return $param;
				}else{
					return $capa_protect_default_comment_author;
				}
			}else{
				return $param;
			}
		}else{
			return $param;
		}

/**
	TODO Editor Comment auch unsichtbar machen?
*/

	}

	// --------------------------------------------------------------------

	function get_value_categories($modus=TRUE,$typ='taxo', $inclusions=array(0),$capa_all_category_ids = array()) {
		global $current_user;

		$all_category_tax_ids = capa_protect::_get_taxonomy_ids();
		$all_category_tax_ids = array_flip($all_category_tax_ids['category']);

		if ($current_user->has_cap('manage_categories') && !$current_user->caps['editor'] ){
			return $all_category_tax_ids;
		}

			$get_valid_category_check = capa_protect::get_capa_protect_for_user($current_user);

		if(is_array($get_valid_category_check)){

				switch($modus){
					case TRUE:
						foreach($get_valid_category_check as $key=>$value){
							$tmp[$all_category_tax_ids[$key]] = TRUE;
						}
					break;

					case FALSE:
						foreach($get_valid_category_check as $key=>$value){
							unset($all_category_tax_ids[$key]);
						}
							$tmp = array_flip($all_category_tax_ids);
					break;
				}

			// Taxonomy ID oder Term ID verlang? Default 'taxo'
				$tmp = ($typ == 'taxo') ? $tmp : array_flip($tmp);

				$inclusions = array_keys($tmp);

				(empty($inclusions) || in_array('',$inclusions)) ? $inclusions = array(0) : NULL ;
		}

		return	$inclusions;

	}

	// --------------------------------------------------------------------

	function get_value_tags($modus=TRUE,$ids=array()) {
		global $wpc_all_category_ids;
		global $wpdb;

		$allow_categories		= capa_protect::get_value_categories(TRUE);
		$disallow_categories	= capa_protect::get_value_categories(FALSE);
		$disallow_categories	= (is_array($disallow_categories)) ? $disallow_categories : array(0);

		$query = '
		SELECT '.$wpdb->term_relationships.'.object_id, '.$wpdb->term_relationships.'.term_taxonomy_id 
			FROM '.$wpdb->term_relationships.' 
				WHERE 
					'.$wpdb->term_relationships.'.object_id IN(SELECT '.$wpdb->term_relationships.'.object_id 
									FROM '.$wpdb->term_relationships.' 
										WHERE '.$wpdb->term_relationships.'.term_taxonomy_id IN ( '.implode(',',$allow_categories).' ) 
											AND '.$wpdb->term_relationships.'.term_taxonomy_id NOT IN ( '.implode(',',$disallow_categories).' )) 
					AND '.$wpdb->term_relationships.'.term_taxonomy_id NOT IN ('.implode(',',$allow_categories).') 
				GROUP BY '.$wpdb->term_relationships.'.term_taxonomy_id
		';

		$res = mysql_query($query) or die(mysql_error());

		while ($row = mysql_fetch_assoc($res))
			$ids[] = $row['term_taxonomy_id'];

		return $ids;
	}

	// --------------------------------------------------------------------

	function get_valid_pages($inclusions=FALSE){

		global $access_pag_anonymous;
		global $access_pag_default;

		$current_user = wp_get_current_user();

		if ($current_user->has_cap('manage_categories') && !$current_user->caps['editor']){
			return false;
		}

			if ($current_user->id == 0){
				$user_access_page_check = $access_pag_anonymous;
			}
			else{
				$current_user_role = 'capa_protect_pag_role_'.implode('',$current_user->roles);
				$user_access_page_check = get_option($current_user_role);
				$user_access_page_check = ($user_access_page_check) ? $user_access_page_check : get_option("capa_protect_pag_user_{$current_user->id}");
			}

			if (empty($user_access_page_check)){
				$user_access_page_check	= $access_pag_default;
			}

			if(is_array($user_access_page_check)){
				$inclusions = array_keys($user_access_page_check,TRUE);	
			}

			return $inclusions;
	}

	// --------------------------------------------------------------------
	// If the user saves a post in a category or categories from which they are
	// restricted, remove the post from the restricted category(ies).  If there
	// are no categories left, save it as Uncategorized with status 'Saved'.
	function verify_category($post_ID) {
		global $wpdb;
	
		$postcats = $wpdb->get_col("SELECT term_taxonomy_id FROM $wpdb->term_relationships WHERE object_id = $post_ID ORDER BY term_taxonomy_id");
		$exclusions = capa_protect::get_value_categories(FALSE);

		if (count($exclusions) && $exclusions != TRUE) {
			$exclusions = implode(", ", $exclusions);
			$wpdb->query("DELETE FROM $wpdb->term_relationships WHERE object_id = $post_ID AND term_taxonomy_id IN ($exclusions)");
			$good_cats = $wpdb->get_var("SELECT COUNT(*) FROM $wpdb->term_relationships WHERE object_id = $post_ID");

			if (0 == $good_cats) {
				$wpdb->query("INSERT INTO $wpdb->term_relationships (`object_id`, `term_taxonomy_id`) VALUES ($post_ID, 1)");
				$wpdb->query("UPDATE $wpdb->posts SET post_status = 'draft' WHERE ID = $post_ID");
			}
		}
	}

	// List of Category at Admin Area ( Edit / New Post )
	function filter_wp_admin_category_list($category){

		global $capa_protect_advance_policy;

		if($capa_protect_advance_policy){
			global $current_user;

			if ($current_user->has_cap('manage_categories'))
				return $category;
	
			global $wpc_all_category_ids;
			global $current_user;
			$count = count($category);

			for($e=0;$e<=$count;$e++){
				if(!capa_protect::user_can_access($category[$e]['cat_ID'],$current_user,'cat')){	
					if(count($category[$e]['children']) > 0){
						$count_children = count($category[$e]['children']);
						for($f=0;$f<=$count_children;$f++){
							if(!empty($category[$e]['children'][$f]['cat_ID'])){
								if(capa_protect::user_can_access($category[$e]['children'][$f]['cat_ID'],$current_user,'cat')){
									$tmp_main = array(	'children'	=>array(),
														'cat_ID'	=>$category[$e]['children'][$f]['cat_ID'],
														'checked'	=>$category[$e]['children'][$f]['checked'],
														'cat_name'	=>$category[$e]['children'][$f]['cat_name']);
									array_push($category,$tmp_main);								
								}
							}
						}					
					}
					unset($category[$e]);
				}
			}
		}

		return $category;
	}

	// --------------------------------------------------------------------
	function filter_category_tags($params){

		global $current_user;
		global $capa_protect_show_private_categories;	

			if ($current_user->has_cap('manage_categories') && !$current_user->caps['editor']){
				return $params;
			}

			if ($capa_protect_show_private_categories){
				return $params;
			}

					sort($params);
					reset($params);
		$count	=	count($params);

		$allow_tags	= capa_protect::get_value_tags(TRUE);
		$category	= capa_protect::get_value_categories(TRUE);

		for($e=0;$e<=$count;$e++){
		// Remove Only taxonomy kind Category

			if($params[$e]->taxonomy == 'category' && strpos($_SERVER['REQUEST_URI'], '/wp-admin/') != true){
				if(!in_array($params[$e]->term_taxonomy_id,$category)){
					unset($params[$e]);
				}
			}elseif($params[$e]->taxonomy == 'post_tag'){
				if(!in_array($params[$e]->term_taxonomy_id,$allow_tags)){
					unset($params[$e]);
				}
			}
		}

		return $params;
	}

	function filter_pages_param($param){

		if(array_key_exists('post_type',$param)){
			global $current_user;

			$exclusions = capa_protect::get_valid_pages(FALSE);

			if(is_array($exclusions)){
				$param['page_id'] = implode(',',$exclusions);
			}
		}
		
		return $param;

	}

	// Extent SQL Query for Category
	// Show only allow Category 
	function sql_terms_exclusions(){

		global $current_user;
		global $capa_protect_show_private_categories;

		if($capa_protect_show_private_categories && strpos($_SERVER['REQUEST_URI'], '/wp-admin/') != true){
			return "";
		}

		if ($current_user->has_cap('manage_categories') && !$current_user->caps['editor']){
			return "";
		}

	// Anyonmous wont get any category 
		if($current_user->id != 0){
			$disallow_categories = capa_protect::get_value_categories(FALSE,'term');

			if(isset($disallow_categories[0]) && $disallow_categories[0] == 0){
				return "AND t.term_id IN ( 0 )";
			}else{
				return "AND t.term_id NOT IN (".implode(',',$disallow_categories).")";
			}
		}
	}

	function filter_has_cap($params){

		if(strpos($_SERVER['REQUEST_URI'], '/wp-admin/page.php')){

#			$allow_pages = capa_protect::get_valid_pages();

#var_dump($allow_pages);
#			if(in_array(get_post()->ID,$allow_pages) || $params['level_8']){
#				return $params;
#			}

		}else{
			return $params;
		}
	}
	
	function cleanup_capa_help($params){
	// Remove Other Help from Wordpress
		return preg_replace('_<h5>' . __('Other Help') . '</h5><div class="metabox-prefs"><a href="http://codex(.*)</div>_', '', $params);
	}
	
	// --------------------------------------------------------------------
	/**
		CaPa intern functions
	*/
	// --------------------------------------------------------------------

// diese Funktion erstellt ein Array mit term_id und term_taxonomy_id ( damit keine verwechslung mehr auftaucht )
	function _get_taxonomy_ids($taxonomy_ids = array()){
		global $wpdb;

			$query = " SELECT term_id,term_taxonomy_id,taxonomy FROM $wpdb->term_taxonomy ";
			$res = mysql_query($query) or die(mysql_error());

				while ($row = mysql_fetch_assoc($res)){
					$taxonomy_ids[$row['taxonomy']][$row['term_taxonomy_id']] = $row['term_id'];
				}

		return $taxonomy_ids;

	}

}


// Clean Up Option DB
function unset_capa_protect_options(){
	delete_option('capa_protect_private_message');
	delete_option('capa_protect_post_policy');
	delete_option('capa_protect_show_padlock_on_private_posts');

	delete_option('capa_protect_show_title_in_feeds');

	delete_option("capa_protect_comment_policy");
	delete_option("capa_protect_show_comment_on_private_posts");

	delete_option('capa_protect_show_private_categories');
	delete_option('capa_protect_show_padlock_on_private_categories');

	delete_option('capa_protect_show_private_pages');

	delete_option("capa_protect_advance_policy");

	delete_option("capa_protect_cat_default");
	delete_option("capa_protect_cat_anonymous");

	delete_option("capa_protect_pag_default");
	delete_option("capa_protect_pag_anonymous");

	delete_option("capa_protect_cat_role_editor");
	delete_option("capa_protect_cat_role_author");
	delete_option("capa_protect_cat_role_contributor");
	delete_option("capa_protect_cat_role_subscriber");

	delete_option("capa_protect_pag_role_editor");
	delete_option("capa_protect_pag_role_author");
	delete_option("capa_protect_pag_role_contributor");
	delete_option("capa_protect_pag_role_subscriber");
	
	global $wpdb;
	$user_ids = $wpdb->get_results( "SELECT ID FROM $wpdb->users ORDER BY ID" );
	$user_ids_count = count($user_ids);

	for($i=0; $i<=$user_ids_count; $i++){
		delete_option("capa_protect_cat_user_".$user_ids[$i]->ID);
		delete_option("capa_protect_pag_user_".$user_ids[$i]->ID);
	}
	
	delete_option("capa_protect_comment_policy");
	delete_option("capa_protect_show_comment_on_private_posts");
	
	delete_option("capa_protect_advance_policy");
	
}

register_deactivation_hook(__FILE__,'unset_capa_protect_options');

// --------------------------------------------------------------------

add_filter('contextual_help',		array('capa_protect','cleanup_capa_help'),10);
#add_action('save_post',					array('capa_protect','verify_category'), 10);

add_filter('wp_list_pages_excludes',	array('capa_protect','filter_page_list_item'),10);
		add_filter('wp_list_categories',		array('capa_protect','filter_category_list_item'),10);

// FRONTEND & BACKEND
add_filter('get_terms',					array('capa_protect','filter_category_tags'),10);

	// FRONTED ?
	// BACKEND Admin (Edit/New Post)
	add_filter('list_terms_exclusions',		array('capa_protect','sql_terms_exclusions'),10);

// Andere Loesung finden
###
#	add_filter('user_has_cap',				array('capa_protect','filter_has_cap'),10);

	// BACKEND Edit-Page.php
	add_filter('manage_pages_query',		array('capa_protect','filter_pages_param'),10);

	// FRONTEND & BACKEND
	add_filter('posts_where',				array('capa_protect','filter_posts'),10);

###
#add_filter('get_pages',					array('capa_protect','filter_pages'),10);

// POST
	add_filter('the_content',				array('capa_protect','filter_content'),10);
##
	add_filter('the_title',					array('capa_protect','filter_post_title'),10);
#	add_filter('the_title', 				array('capa_protect','post_padlock'),10);

add_filter('get_previous_post_where',	array('capa_protect','filter_posts'),10);
add_filter('get_next_post_where', 		array('capa_protect','filter_posts'),10);
add_filter('getarchives_where',			array('capa_protect','filter_posts'),10);

	add_filter('get_comment',				array('capa_protect','filter_comment'),10);
	add_filter('get_comment_author_link',	array('capa_protect','filter_comment_author'),10);
	add_filter('comment_author',			array('capa_protect','filter_comment_author'),10);
	add_filter('comment_text',				array('capa_protect','filter_comment_body'),10);
?>